@@ -1,8 +1,12 @@
-use strict;
-use warnings;
+use 5.012;
+use MooseX::Declare;
+use Method::Signatures::Modifiers;
 
+class Pod::Weaver::PluginBundle::BAREFOOT
 {
-	package Pod::Weaver::PluginBundle::BAREFOOT;
+	use autodie										2.00				;
+	use MooseX::Has::Sugar												;
+	use MooseX::Types::Moose									':all'	;
 
 	# Dependencies
 	use Pod::Weaver 3.101635; # fixed ABSTRACT scanning
@@ -13,7 +17,8 @@ use warnings;
 	use Pod::Weaver::Section::Support 1.001 ();
 
 
-	our $VERSION = '0.03'; # VERSION
+	our $VERSION = '0.04'; # VERSION
+
 
 	my $bugtracker_content = <<'END';
 		This module is on GitHub.  Feel free to fork and submit patches.  Please note that I develop
@@ -25,13 +30,20 @@ use warnings;
 END
 
 
-	sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
+	method _exp { Pod::Weaver::Config::Assembler->expand_package($self) }
 
-	sub mvp_bundle_config
+	method mvp_bundle_config ($class: ...)
 	{
+		# get payload (configurable parameters) from the dzil plugin bundle
+		my $payload = Dist::Zilla::PluginBundle::BAREFOOT->weaver_payload;
+
+		# now set default values for them
+		$payload->{'repository_link'}	//= 'both';
+
 		my @plugins;
 		push @plugins, (
 			[ '@BAREFOOT/WikiDoc',     _exp('-WikiDoc'),	{} ],
+
 			[ '@BAREFOOT/CorePrep',    _exp('@CorePrep'),	{} ],
 			[ '@BAREFOOT/Name',        _exp('Name'),		{} ],
 			[ '@BAREFOOT/Version',     _exp('Version'),		{
@@ -39,16 +51,15 @@ END
 															}
 			],
 
-			#[ '@BAREFOOT/Prelude',     _exp('Region'),		{ region_name => 'prelude'     } ],
 			[ '@BAREFOOT/Synopsis',    _exp('Generic'),		{ header      => 'SYNOPSIS'    } ],
 			[ '@BAREFOOT/Description', _exp('Generic'),		{ header      => 'DESCRIPTION' } ],
 			[ '@BAREFOOT/Overview',    _exp('Generic'),		{ header      => 'OVERVIEW'    } ],
 		);
 
 		for my $plugin (
-			[ 'Attributes', _exp('Collect'),				{ command => 'attr'   } ],
-			[ 'Methods',    _exp('Collect'),				{ command => 'method' } ],
-			[ 'Functions',  _exp('Collect'),				{ command => 'func'   } ],
+			[ 'Attributes', 			_exp('Collect'),	{ command => 'attr'   } ],
+			[ 'Methods',    			_exp('Collect'),	{ command => 'method' } ],
+			[ 'Functions',  			_exp('Collect'),	{ command => 'func'   } ],
 		){
 			$plugin->[2]->{'header'} = uc $plugin->[0];
 			push @plugins, $plugin;
@@ -61,7 +72,7 @@ END
 																websites			=> 'none',
 																bugs				=> 'metadata',
 																bugs_content		=> $bugtracker_content,
-																repository_link		=> 'both',
+																repository_link		=> $payload->{'repository_link'},
 																repository_content	=> 'none',
 															}
 			],
@@ -90,7 +101,7 @@ Pod::Weaver::PluginBundle::BAREFOOT - BAREFOOT's default Pod::Weaver config
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of Pod::Weaver::PluginBundle::BAREFOOT.
 
 =head1 DESCRIPTION
 
@@ -99,14 +110,35 @@ following weaver.ini:
 
    [-WikiDoc]
  
-   [@Default]
+   [@CorePrep]
  
+   [Name]
+   [Version]
+ 
+   [Generic / SYNOPSIS]
+   [Generic / DESCRIPTION]
+   [Generic / OVERVIEW]
+ 
+   [Collect / ATTRIBUTES]
+   command = attr
+ 
+   [Collect / METHODS]
+   command = method
+ 
+   [Collect / FUNCTIONS]
+   command = func
+ 
+   [Leftovers]
    [Support]
    perldoc = 1
    websites = none
    bugs = metadata
    bugs_content = ... stuff (web only, email omitted) ...
-   repository_link = none
+   repository_link = both
+   repository_content = none
+ 
+   [Authors]
+   [Legal]
  
    [-Transformer]
    transfomer = List
@@ -146,7 +178,7 @@ Buddy Burden <barefoot@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Buddy Burden.
+This software is Copyright (c) 2015 by Buddy Burden.
 
 This is free software, licensed under:
 
